
from flask import Flask, request, render_template, redirect, abort, url_for
from flask_cloudy import Storage

app = Flask(__name__)

app.config.update({
    "STORAGE_PROVIDER": "LOCAL",
    "STORAGE_CONTAINER": "./data",
    "STORAGE_KEY": "",
    "STORAGE_SECRET": "",
    "STORAGE_SERVER": True
})

storage = Storage()
storage.init_app(app)

@app.route("/")
def index():

    return render_template("index.html", storage=storage)

@app.route("/view/<path:object_name>")
def view(object_name):
    obj = storage.get(object_name)
    print obj.name
    return render_template("view.html", obj=obj)

@app.route("/upload", methods=["POST"])
def upload():
    file = request.files.get("file")
    my_object = storage.upload(file)
    return redirect(url_for("view", object_name=my_object.name))


if __name__ == "__main__":
    app.run(debug=True, port=5000)


"""
Flask-Cloudy

A wrapper around Apache-Libcloud to upload and save files on cloud storage
providers such as: AWS S3, Google Storage, Microsoft Azure, Rackspace Cloudfiles,
and even on local storage through a Flask application.
(It can be used as standalone)

Supported storage:

- AWS S3
- Google Storage
- Microsoft Azure
- Rackspace CloudFiles
- Local

"""

from setuptools import setup, find_packages

__NAME__ = "Flask-Cloudy"
__version__ = "1.0.1"
__author__ = "Mardix"
__license__ = "MIT"
__copyright__ = "2017"

setup(
    name=__NAME__,
    version=__version__,
    license=__license__,
    author=__author__,
    author_email='mardix@github.com',
    description="Flask-Cloudy is a simple flask extension and standalone library to upload and save files on S3, Google storage or other Cloud Storages",
    long_description=__doc__,
    url='https://github.com/mardix/flask-cloudy/',
    download_url='http://github.com/mardix/flask-cloudy/tarball/master',
    py_modules=['flask_cloudy'],
    include_package_data=True,
    packages=find_packages(),
    install_requires=[
        "Flask>=0.10.1",
        "apache-libcloud==0.20.1",
        "lockfile>=0.10.2",
        "six>=1.9.0",
        'python-slugify>=1.2.1'
    ],

    keywords=["flask", "s3", "aws", "cloudfiles", "storage", "azure", "google", "cloudy"],
    platforms='any',
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    zip_safe=False
)

